import requests
from bs4 import BeautifulSoup
from fake_useragent import UserAgent

def get_html(url,encode='utf-8',timeout=30,ssl_error=False):
    useragent = UserAgent(verify_ssl=False).random if ssl_error else UserAgent().random
    try:
        headers = {
            "User-Agent": useragent,
            "Connection": "close"
        }
        r = requests.get(url, timeout=timeout, headers=headers)
        r.encoding = encode
        if r.status_code != 200:
            r.raise_for_status()
        return r.text
    except requests.HTTPError:
        return ""

def crawl_url(url,encode='utf-8',selector='',save_path='',timeout=30,debug=False,ssl_error=False):
    html = get_html(url,encode=encode,timeout=timeout,ssl_error=ssl_error)
    if html:
        if debug: print(html)
        if selector:
            soup = BeautifulSoup(html, 'html.parser')
            find_soup = soup.select(selector)
            print('数据个数:', len(find_soup))
            for f in find_soup:
                name = f.text.strip() or ''
                href = f["href"] or ''
                if debug: print(name, href)
                if save_path:
                    with open(save_path, 'a', encoding='utf-8') as fw:
                        fw.write(href + ',' + name + '\n')
        else:
            return html
    else:
        print('网址错误，请检查.')

def post_api_url(url,data):
    r = requests.post(url, json = data, headers={"Connection": "close"})
    if r.status_code != 200:
        r.raise_for_status()
    return r.json()

def get_api_url(url):
    r = requests.get(url, headers={"Connection": "close"})
    if r.status_code != 200:
        r.raise_for_status()
    return r.json()



from crsspd.req_tools import *
from crsspd.selm_tools import SelenuimTools

class SpiderTools():
    def __init__(self,chrome_path='/Users/bappy/Opt/chromedriver',headless=True):
        self.selm=SelenuimTools(chrome_path=chrome_path,headless=headless)

    def request(self):
        pass

    def selenuim(self):
        pass

    def scrapy(self):
        pass

    def splash(self):
        pass

    def get_url(self,url,dynamic=False,wait_time=1,wait_show='',ssl_error=False):
        if not dynamic:
            return get_html(url,ssl_error=ssl_error)
        else:
            return self.selm.get_html(url,wait_time=wait_time,wait_show=wait_show)

    def get_proxy(self):
        proxy_list=self.selm.get_proxy_by_selenium()
        return proxy_list

if __name__ == '__main__':
    import tempfile
    print(tempfile.gettempdir())
    url='http://proxylist.fatezero.org/'

    spd = SpiderTools(headless=False)
    html=spd.get_url(url,dynamic=True,wait_time=10,ssl_error=False)
    print(html)


